package App::dt;

our $DATE = '2019-11-26'; # DATE
our $VERSION = '0.006'; # VERSION

1;
# ABSTRACT: CLI data transformer

__END__

=pod

=encoding UTF-8

=head1 NAME

App::dt - CLI data transformer

=head1 VERSION

This document describes version 0.006 of App::dt (from Perl distribution App-dt), released on 2019-11-26.

=head1 SYNOPSIS

See the command-line script L<dt>.

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/App-dt>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-App-dt>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-dt>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2019, 2017 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
